=========
Changelog
=========

0.2.0 (2015-12-03)
------------------

- Switch to unittest + nose for tests
- Tested with Python 2.7, 3.3, 3.4, 3.5
- Don't force the AWS region to us-east-1


0.1.4 (2015-12-02)
------------------

- Allow workflows to raise an exception to fail an execution


0.1.3 (2015-11-24)
------------------

- Release again to fix PyPI upload server error


0.1.2 (2015-11-24)
------------------

- Fix crash with --logging-config


0.1.1 (2015-11-23)
------------------

- Add command caravan-terminate
- Make --modules as config key works


0.1.0 (2015-11-19)
------------------

- Add command caravan-domain-register
- Add command caravan-list


0.0.2 (2015-11-12)
------------------

- First release on Pypi


0.0.1 (unreleased)
------------------

- Initial setup
